@@ -3,10 +3,11 @@ echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
 echo "" 												>> $EXTENSION/build_order.txt
 	
 # Required
+source /etc/profile.d/xorg.sh
 [ ! -f /etc/profile.d/xorg.sh ] && echo "Installing xorg_build_env" && extension --install xorg_build_env && echo "Finished xorg_build_env"
 source /etc/profile.d/xorg.sh
 
-if [ $BUILD_ALL == "false" ] && [[ ! -d $XORG_PREFIX/share/util-macros ]]; then
+if [ $BUILD_ALL == "false" ] && [ ! -d $XORG_PREFIX/share/util-macros ]; then
 	echo "util_macros" 									>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
